pub enum UndoTarget {
Last,
Version(MigrationVersion),
Count(usize),
}Expand description
How many / which versions to undo.
Last and Count walk the currently-applied versions in descending
version order, which is not necessarily installation order — with
out_of_order enabled a lower version can be installed later. Undo is
defined on version order so that it is the inverse of migrate.
Variants
Last
Undo the highest currently-applied version.
Version(MigrationVersion)
Undo all migrations above this version (the target version itself stays applied).
Count(usize)
Undo the N highest currently-applied versions, highest first.