pub struct HooksConfig {
pub before_migrate: Vec<PathBuf>,
pub after_migrate: Vec<PathBuf>,
pub before_each_migrate: Vec<PathBuf>,
pub after_each_migrate: Vec<PathBuf>,
}Expand description
Hook configuration for running SQL before/after migrations.
Fields
before_migrate: Vec<PathBuf>SQL scripts to run once before the entire migration run.
after_migrate: Vec<PathBuf>SQL scripts to run once after the entire migration run.
before_each_migrate: Vec<PathBuf>SQL scripts to run before each individual migration.
after_each_migrate: Vec<PathBuf>SQL scripts to run after each individual migration.