pub struct ResolvedHook {
pub hook_type: HookType,
pub script_name: String,
pub sql: String,
}Expand description
A hook SQL script discovered on disk or specified in config.
Fields
hook_type: HookTypeThe phase at which this hook should be executed.
script_name: StringFilename of the hook SQL script.
sql: StringRaw SQL content of the hook file.