pub struct SafetyConfig {
pub enabled: bool,
pub block_on_danger: bool,
pub large_table_threshold: i64,
pub huge_table_threshold: i64,
}Expand description
Configuration for safety analysis.
Fields
enabled: boolWhether safety analysis is enabled.
block_on_danger: boolWhether to block migrations that receive a DANGER verdict.
large_table_threshold: i64Row count threshold for classifying a table as Large.
huge_table_threshold: i64Row count threshold for classifying a table as Huge.