DdlOperation

Enum DdlOperation 

pub enum DdlOperation {
Show 16 variants CreateTable { table: String, if_not_exists: bool, }, DropTable { table: String, }, AlterTableAddColumn { table: String, column: String, data_type: String, has_default: bool, is_not_null: bool, }, AlterTableDropColumn { table: String, column: String, }, AlterTableAlterColumn { table: String, column: String, }, CreateIndex { name: String, table: String, is_concurrent: bool, is_unique: bool, }, DropIndex { name: String, }, CreateView { name: String, is_materialized: bool, }, DropView { name: String, }, CreateFunction { name: String, }, DropFunction { name: String, }, AddConstraint { table: String, constraint_type: String, }, DropConstraint { table: String, name: String, }, CreateEnum { name: String, }, TruncateTable { table: String, }, Other { statement_preview: String, },
}
A DDL operation extracted from SQL.

Variants



CreateTable

A CREATE TABLE statement.

Fields

table: String

Name of the table being created.

if_not_exists: bool

Whether the statement includes IF NOT EXISTS.



DropTable

A DROP TABLE statement.

Fields

table: String

Name of the table being dropped.



AlterTableAddColumn

An ALTER TABLE … ADD COLUMN statement.

Fields

table: String

Name of the table being altered.

column: String

Name of the column being added.

data_type: String

Data type of the new column.

has_default: bool

Whether the column has a DEFAULT expression.

is_not_null: bool

Whether the column has a NOT NULL constraint.



AlterTableDropColumn

An ALTER TABLE … DROP COLUMN statement.

Fields

table: String

Name of the table being altered.

column: String

Name of the column being dropped.



AlterTableAlterColumn

An ALTER TABLE … ALTER COLUMN statement.

Fields

table: String

Name of the table being altered.

column: String

Name of the column being modified.



CreateIndex

A CREATE INDEX statement.

Fields

name: String

Name of the index being created.

table: String

Name of the table the index is on.

is_concurrent: bool

Whether the index is created CONCURRENTLY.

is_unique: bool

Whether this is a UNIQUE index.



DropIndex

A DROP INDEX statement.

Fields

name: String

Name of the index being dropped.



CreateView

A CREATE VIEW or CREATE MATERIALIZED VIEW statement.

Fields

name: String

Name of the view being created.

is_materialized: bool

Whether this is a materialized view.



DropView

A DROP VIEW statement.

Fields

name: String

Name of the view being dropped.



CreateFunction

A CREATE FUNCTION statement.

Fields

name: String

Name of the function being created.



DropFunction

A DROP FUNCTION statement.

Fields

name: String

Name of the function being dropped.



AddConstraint

An ALTER TABLE … ADD CONSTRAINT statement.

Fields

table: String

Name of the table the constraint is added to.

constraint_type: String

Type of constraint (e.g. PRIMARY KEY, UNIQUE, FOREIGN KEY).



DropConstraint

An ALTER TABLE … DROP CONSTRAINT statement.

Fields

table: String

Name of the table the constraint is dropped from.

name: String

Name of the constraint being dropped.



CreateEnum

A CREATE TYPE … AS ENUM statement.

Fields

name: String

Name of the enum type being created.



TruncateTable

A TRUNCATE TABLE statement.

Fields

table: String

Name of the table being truncated.



Other

Any other SQL statement that does not match known DDL patterns.

Fields

statement_preview: String

Truncated preview of the unrecognized statement.