Waypoint

Struct Waypoint 

pub struct Waypoint {
    pub config: WaypointConfig,
    /* private fields */
}
Main entry point for the Waypoint library.

Create a Waypoint instance with a config and use its methods to run migration commands programmatically.

Fields

config: WaypointConfig

Implementations

Source

impl Waypoint

pub async fn new(config: WaypointConfig) -> Result<Self>

Create a new Waypoint instance, connecting to the database.

If connect_retries is configured, retries with exponential backoff.

pub fn with_client(config: WaypointConfig, client: Client) -> Self

Create a new Waypoint instance with an existing database client.

pub async fn migrate( &self, target_version: Option<&str>, ) -> Result<MigrateReport>

Apply pending migrations.

pub async fn info(&self) -> Result<Vec<MigrationInfo>>

Show migration status information.

pub async fn validate(&self) -> Result<ValidateReport>

Validate applied migrations against local files.

pub async fn repair(&self) -> Result<RepairReport>

Repair the schema history table.

pub async fn baseline( &self, version: Option<&str>, description: Option<&str>, ) -> Result<()>

Baseline an existing database.

pub async fn clean(&self, allow_clean: bool) -> Result<Vec<String>>

Drop all objects in managed schemas.